import { SerializedValueProvider } from "./request-serializer";
export type CacheRecord<K extends string | number> = Record<K, {
    lastFetchTimestamp: number;
} | undefined>;
export interface ICacheDataContainer<T, K extends any[]> {
    resetCache(...args: K): void;
    getValue(...args: K): Promise<T | undefined>;
    setValue(value: T, ...args: K): Promise<void>;
}
export declare class CachedDataContainer<T, K extends any[]> implements ICacheDataContainer<T, K> {
    protected readonly valueGetterFn: (...args: K) => Promise<T | undefined>;
    protected readonly valueSetterFn?: ((value: T, ...args: K) => Promise<void>) | undefined;
    protected readonly dataRetentionDurationMs: number;
    protected readonly cache: CacheRecord<string>;
    protected readonly valueProvider: SerializedValueProvider<T | undefined, K>;
    constructor(valueGetterFn: (...args: K) => Promise<T | undefined>, valueSetterFn?: ((value: T, ...args: K) => Promise<void>) | undefined, dataRetentionDurationMs?: number);
    protected getKey(args: K): string;
    resetCache(...args: K): void;
    getValue(...args: K): Promise<T | undefined>;
    setValue(value: T, ...args: K): Promise<void>;
}
