import { SerializedValueProvider } from "./request-serializer";
export class CachedDataContainer {
    valueGetterFn;
    valueSetterFn;
    dataRetentionDurationMs;
    cache = {};
    valueProvider;
    constructor(valueGetterFn, valueSetterFn, dataRetentionDurationMs = 30000) {
        this.valueGetterFn = valueGetterFn;
        this.valueSetterFn = valueSetterFn;
        this.dataRetentionDurationMs = dataRetentionDurationMs;
        this.valueProvider = new SerializedValueProvider(this.valueGetterFn);
    }
    getKey(args) {
        return args.map((arg) => String(arg)).join(":");
    }
    resetCache(...args) {
        const key = this.getKey(args);
        const cache = this.cache[key];
        if (cache) {
            cache.lastFetchTimestamp = 0;
        }
    }
    async getValue(...args) {
        const key = this.getKey(args);
        let cache = this.cache[key];
        if (!cache) {
            cache = {
                lastFetchTimestamp: 0,
            };
            this.cache[key] = cache;
        }
        let value;
        if (cache.lastFetchTimestamp + this.dataRetentionDurationMs < Date.now()) {
            value = await this.valueProvider.getValue(...args);
            cache.lastFetchTimestamp = Date.now();
        }
        return value;
    }
    async setValue(value, ...args) {
        const key = this.getKey(args);
        let cache = this.cache[key];
        if (!cache) {
            cache = {
                lastFetchTimestamp: Date.now(),
            };
            this.cache[key] = cache;
        }
        await this.valueSetterFn?.(value, ...args);
    }
}
